==> wikitty-api-3.6-sources.jar: org/nuiton/wikitty/entities/WikittyTreeNode.java <==
package org.nuiton.wikitty.entities;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.WikittyUtil;

public interface WikittyTreeNode extends BusinessEntity {

    String EXT_WIKITTYTREENODE = "WikittyTreeNode";

    String FIELD_WIKITTYTREENODE_NAME = "name";

    String FQ_FIELD_WIKITTYTREENODE_NAME = EXT_WIKITTYTREENODE + ".name";

    ElementField ELEMENT_FIELD_WIKITTYTREENODE_NAME = new ElementField(FQ_FIELD_WIKITTYTREENODE_NAME);

    String FIELD_WIKITTYTREENODE_ATTACHMENT = "attachment";

    String FQ_FIELD_WIKITTYTREENODE_ATTACHMENT = EXT_WIKITTYTREENODE + ".attachment";

    ElementField ELEMENT_FIELD_WIKITTYTREENODE_ATTACHMENT = new ElementField(FQ_FIELD_WIKITTYTREENODE_ATTACHMENT);

    String FIELD_WIKITTYTREENODE_PARENT = "parent";

    String FQ_FIELD_WIKITTYTREENODE_PARENT = EXT_WIKITTYTREENODE + ".parent";

    ElementField ELEMENT_FIELD_WIKITTYTREENODE_PARENT = new ElementField(FQ_FIELD_WIKITTYTREENODE_PARENT);

    String getName();

    void setName(String name);

    Set<String> getAttachment();

    void setAttachment(Set<String> attachment);

    void addAllAttachment(Collection<String> attachment);

    void addAttachment(String... element);

    void removeAttachment(String... element);

    void clearAttachment();

    String getParent();

    void setParent(String parent);

    WikittyTreeNode getParent(boolean exceptionIfNotLoaded);

    void setParent(WikittyTreeNode parent);

} //WikittyTreeNode

==> wikitty-api-3.8-sources.jar: org/nuiton/wikitty/entities/WikittyTreeNode.java <==
package org.nuiton.wikitty.entities;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.WikittyUtil;

public interface WikittyTreeNode extends BusinessEntity {

    String EXT_WIKITTYTREENODE = "WikittyTreeNode";

    String FIELD_WIKITTYTREENODE_NAME = "name";

    String FQ_FIELD_WIKITTYTREENODE_NAME = EXT_WIKITTYTREENODE + ".name";

    ElementField ELEMENT_FIELD_WIKITTYTREENODE_NAME = new ElementField(FQ_FIELD_WIKITTYTREENODE_NAME);

    String FIELD_WIKITTYTREENODE_ATTACHMENT = "attachment";

    String FQ_FIELD_WIKITTYTREENODE_ATTACHMENT = EXT_WIKITTYTREENODE + ".attachment";

    ElementField ELEMENT_FIELD_WIKITTYTREENODE_ATTACHMENT = new ElementField(FQ_FIELD_WIKITTYTREENODE_ATTACHMENT);

    String FIELD_WIKITTYTREENODE_PARENT = "parent";

    String FQ_FIELD_WIKITTYTREENODE_PARENT = EXT_WIKITTYTREENODE + ".parent";

    ElementField ELEMENT_FIELD_WIKITTYTREENODE_PARENT = new ElementField(FQ_FIELD_WIKITTYTREENODE_PARENT);

    String getName();

    void setName(String name);

    Set<String> getAttachment();

    void setAttachment(Set<String> attachment);

    void addAllAttachment(Collection<String> attachment);

    void addAttachment(String... element);

    void removeAttachment(String... element);

    void clearAttachment();

    Set<Wikitty> getAttachment(boolean exceptionIfNotLoaded);

    void setAttachmentEntity(Collection<Wikitty> attachment);

    void addAllAttachmentEntity(Collection<Wikitty> attachment);

    void addAttachment(Wikitty... element);

    void removeAttachment(Wikitty... element);

    String getParent();

    void setParent(String parent);

    WikittyTreeNode getParent(boolean exceptionIfNotLoaded);

    void setParent(WikittyTreeNode parent);

} //WikittyTreeNode
